{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "Workflow including checker to compare VCFs using GATK Concordance tool.\n",
            "id": "#main",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/reference",
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ]
                },
                {
                    "id": "#main/eval",
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ]
                },
                {
                    "id": "#main/truth",
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ]
                },
                {
                    "id": "#main/summary",
                    "type": "string"
                },
                {
                    "id": "#main/threshold",
                    "type": "float"
                }
            ],
            "steps": [
                {
                    "id": "#main/GATKConcordance",
                    "run": "#GATKConcordance.yaml.cwl",
                    "in": [
                        {
                            "id": "#main/GATKConcordance/reference",
                            "source": "#main/reference"
                        },
                        {
                            "id": "#main/GATKConcordance/eval",
                            "source": "#main/eval"
                        },
                        {
                            "id": "#main/GATKConcordance/truth",
                            "source": "#main/truth"
                        },
                        {
                            "id": "#main/GATKConcordance/summary",
                            "source": "#main/summary"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/GATKConcordance/concordance_summary"
                        }
                    ]
                },
                {
                    "id": "#main/ConcordanceChecker",
                    "run": "#GATKConcordanceChecker.yaml.cwl",
                    "in": [
                        {
                            "id": "#main/ConcordanceChecker/summary",
                            "source": "#main/GATKConcordance/concordance_summary"
                        },
                        {
                            "id": "#main/ConcordanceChecker/threshold",
                            "source": "#main/threshold"
                        }
                    ],
                    "out": []
                }
            ],
            "outputs": [
                {
                    "id": "#main/concordance_summary",
                    "type": "File",
                    "outputSource": "#main/GATKConcordance/concordance_summary"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "GATK Concordance tool to compare overlapping variants in two VCFs.\n",
            "id": "#GATKConcordance.yaml.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "us.gcr.io/broad-gotc-prod/genomes-in-the-cloud:2.3.2-1510681135"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000
                }
            ],
            "baseCommand": [
                "/usr/gitc/gatk4/gatk-launch",
                "Concordance"
            ],
            "arguments": [
                {
                    "valueFrom": "-XX:GCHeapFreeLimit=10 -XX:+PrintFlagsFinal -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+PrintGCDetails -Xloggc:gc_log.log -Xms4000m",
                    "position": 0,
                    "prefix": "--javaOptions",
                    "separate": true
                }
            ],
            "inputs": [
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/reference",
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "inputBinding": {
                        "prefix": "-R"
                    }
                },
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/eval",
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "prefix": "-eval"
                    }
                },
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/truth",
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "prefix": "--truth"
                    }
                },
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/summary",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--summary"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/concordance_summary",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.summary)"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#GATKConcordanceChecker.yaml.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#GATKConcordanceChecker.yaml.cwl/GATKConcordanceChecker/summary",
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    }
                },
                {
                    "id": "#GATKConcordanceChecker.yaml.cwl/GATKConcordanceChecker/threshold",
                    "type": "float"
                }
            ],
            "outputs": [],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "${\n    var lines = inputs.summary.contents.split(\"\\n\");\n    var flag = 0;\n    var message = \"The VCFs can be considered identical.\";\n    for (var i=1; i < lines.length; i++) {\n        var sensitivity = lines[i].split(\"\\t\")[4];\n        if (sensitivity < inputs.threshold) {\n            message = \"The VCFs do not have enough overlapping.\";\n            flag = 1;\n        }\n        var precision = parseFloat(lines[i].split(\"\\t\")[5]);\n        if (precision < inputs.threshold) {\n            message = \"The VCFs do not have enough overlapping.\";\n            flag = 1;\n        }\n    }\n    var output = \"printf \\\"\" + message + \"\\\\n\\\"; \" + \"exit \" + flag + \";\";\n    return output\n}\n"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0"
}
